import { Command } from '../packages/@molt/command/src/index.js'
import { execa } from 'execa'
import Fs from 'fs-jetpack'
import * as Path from 'node:path'
import url from 'node:url'
import semverRegex from 'semver-regex'
import { z } from 'zod'

const args = Command.create({
  'p package': z.enum([`@molt/command`, `@molt/types`, `molt`]),
  'v version': z.string().regex(semverRegex()),
}).parseOrThrow()

const cwd = Path.join(Path.dirname(url.fileURLToPath(import.meta.url)), `../packages`, args.package)
const $Fs = Fs.cwd(cwd)

const pkg = (await $Fs.readAsync(`package.json`, `json`)) as { name: string; version: string }
await $Fs.writeAsync(`package.json`, JSON.stringify({ ...pkg, version: args.version }, null, 2) + `\n`)
await execa(`git`, [`add`, `package.json`], { cwd })
await execa(`git`, [`commit`, `--message`, `'chore(${args.package}): bump version'`], { stdio: `inherit` })
await execa(`pnpm`, [`publish`], { cwd, stdio: `inherit` })
// prettier-ignore
await execa(`git`, [`tag`, `${args.package}@${args.version}`, `--annotate`, `--message`, `Version ${args.version} for package ${args.package}`], { stdio: `inherit` })
await execa(`git`, [`push`], { stdio: `inherit` })
await execa(`git`, [`push`, `--tags`], { stdio: `inherit` })
